@@ -28,10 +28,10 @@ def rsa_verify(message, signature, key):
     return expected == signature
 
 
-def update_self(to_screen, verbose, opener):
+def update_self(to_screen, verbose, opener, prefer_insecure=False):
     """Update the program file with the latest version from the repository"""
 
-    UPDATE_URL = 'https://rg3.github.io/youtube-dl/update/'
+    UPDATE_URL = '//rg3.github.io/youtube-dl/update/'
     VERSION_URL = UPDATE_URL + 'LATEST_VERSION'
     JSON_URL = UPDATE_URL + 'versions.json'
     UPDATES_RSA_KEY = (0x9d60ee4d8f805312fdb15a62f87b95bd66177b91df176765d13514a0f1754bcd2057295c5b6f1d35daa6742c3ffc9a82d3e118861c207995a8031e151d863c9927e304576bc80692bc8e094896fcf11b66f3e29e04e3a71e9a11558558acea1840aec37fc396fb6b65dc81a1c4144e03bd1c011de62e3f1357b327d08426fe93, 65537)
@@ -40,9 +40,13 @@ def update_self(to_screen, verbose, opener):
         to_screen('It looks like you installed youtube-dl with a package manager, pip, setup.py or a tarball. Please use that to update.')
         return
 
+    def guess_scheme(url, insecure=False):
+        return 'http%s:%s' % ('' if insecure is True else 's', url)
+
     # Check if there is a new version
     try:
-        newversion = opener.open(VERSION_URL).read().decode('utf-8').strip()
+        newversion = opener.open(guess_scheme(
+            VERSION_URL, prefer_insecure)).read().decode('utf-8').strip()
     except Exception:
         if verbose:
             to_screen(encode_compat_str(traceback.format_exc()))
@@ -54,7 +58,8 @@ def update_self(to_screen, verbose, opener):
 
     # Download and check versions info
     try:
-        versions_info = opener.open(JSON_URL).read().decode('utf-8')
+        versions_info = opener.open(guess_scheme(
+            JSON_URL, prefer_insecure)).read().decode('utf-8')
         versions_info = json.loads(versions_info)
     except Exception:
         if verbose:
